#[non_exhaustive]pub enum SomePublicKey {
Rsa(RsaPublicKey),
}Expand description
An RSA, EC or Ed25519 public key.
Use this if you just want to load SOME public key from an external pem file or JWK.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Rsa(RsaPublicKey)